@@ -1,4 +1,3 @@
-
 /*
  * Copyright (C) 1992  Board of Regents of the University of Wisconsin
  * on behalf of the Department of Electrical Engineering and Computer
@@ -60,8 +59,9 @@
    functions defined in scXstuff.c */
 /* 7-31-91 B. Backman -- Removed illegal comparisons of char-pointers to 
    chars */
+
 #include <signal.h>
-/*#include <curses.h> */
+#include "config.h"
 
 
 #ifdef BSD42
@@ -684,7 +684,7 @@ graphic_resetfn()
        else if ( choice != 0 )
           {
           if ( choice == 1 ) {
-            for (i=1; i< GRAPHRESETS; i++)
+            for (i=1; i < GRAPHRANGES; i++)
                 graphic_range[i].col[0] = '\0'; /* set all ranges to NULL */
             sprintf(msg,"Clear the ranges for entire graph !");
           }
