@@ -7,11 +7,12 @@
  *
  *              More mods Robert Bond, 12/86
  *		More mods by Alan Silverstein, 3-4/88, see list of changes.
+ *              More mods by Peter Doemel, 2/93: support for REG_COMP
  *		$Revision: 6.21 A $
  */
 
-#define DEBUGDTS 1		/* REMOVE ME */
-     
+#include "config.h" 
+
 #include <sys/types.h>
 #ifdef aiws
 #undef _C_func			/* Fixes for undefined symbols on AIX */
@@ -59,6 +60,20 @@ char *regcmp();
 char *regex();
 #endif
 
+#if defined(REG_COMP) /* Peter Doemel, 10-Feb-1993 */
+#include <regex.h>
+# if NeedFunctionPrototypes
+  int regcomp(regex_t *preg, const char *pattern, int cflags);
+  int regexec(const regex_t *preg, const char *string, size_t nmatch,
+              regmatch_t pmatch[], int eflags);
+  void regfree(regex_t *preg);
+  char *regerrmsg(interrcode);
+# else
+  char *regerrmsg();
+# endif
+#endif
+  
+
 sig_type doquit();
 
 /* Use this structure to save the the last 'g' command */
@@ -615,15 +630,6 @@ int mo, day, yr;
 		 + tp->tm_min*sec_min + tp->tm_sec;
     }
 
-#ifdef DEBUGDTS
-    tp = localtime(&trial);
-    if (tp->tm_mday + tp->tm_hour + tp->tm_min + tp->tm_sec + 
-	tp->tm_year + tp->tm_mon != yr+mo+day)
-	{	error("Dts broke down");
-		cellerror = CELLERROR;
-	}
-#endif
-
     return ((double)trial);
 }
 
@@ -684,7 +690,8 @@ char *s;
     if (!s)
 	return((double)0);
 
-    (void)strtof(s, &v);
+    v = atof(s);
+    /* (void)strtof(s, &v); */
     scxfree(s);
     return(v);
 }
@@ -1764,7 +1771,62 @@ int	errsearch;
     curcol = c;
 }
 
+#if defined(REG_COMP) /* Peter Doemel, 10-Feb-1993 */
+char *
+regerrmsg(errcode)
+int errcode;
+{
+    switch(errcode) {
+      case REG_NOMATCH:
+          return "regexec() failed to match.";
+      case REG_ECOLLATE:
+          return "Invalid collation element referenced.";
+      case REG_EESCAPE:
+          return "Trailing \\ in pattern.";
+      case REG_ENEWLINE:
+          return "<newline> found before end of pattern and REG_NEWLINE flag not set.";
+      case REG_ESUBREG:
+          return "Number in \\digit invalid or in error.";
+      case REG_EBRACK:
+          return "[ ] imbalance.";
+      case REG_EPAREN:
+          return "\\( \\) imbalance in basic regular expression or ( ) imbalance in extended regular expression.";
+      case REG_EBRACE:
+          return "\\{ \\} imbalance.";
+      case REG_ERANGE:
+          return "Invalid endpoint in range statement.";
+      case REG_ESPACE:
+          return "Out of memory for compiled pattern.";
+      case REG_EMEM:
+          return "Out of memory while matching expression.";
+/*    case REG_EBADRPT:
+          return "Misuse of *, +, or ? in extended regular expression."; */
+      case REG_ECTYPE:
+          return "Invalid character class type named.";
+      case REG_ENSUB:
+          return "Too many parenthesis pairs or nesting level too deep.";
+      case REG_EABRACE:
+          return "Number too large in \\{ \\} construct.";
+      case REG_EBBRACE:
+          return "Invalid number in \\{ \\} construct.";
+      case REG_ECBRACE:
+          return "More than two numbers in \\{ \\} construct.";
+      case REG_EDBRACE:
+          return "First number exceeds second in \\{ \\} construct.";
+      case REG_ENOSEARCH:
+          return "No remembered search string.";
+      case REG_EDUPOPER:
+          return "Duplication operator in illegal position.";
+      case REG_ENOEXPR:
+          return "No expression within ( ) or on one side of an |.";
+      default:
+          return "regerrmsg: INVALID ERRORCODE";
+    }
+}
+#endif
+
 /* 'goto' a cell containing a matching string */
+
 void
 str_search(s)
 char *s;
@@ -1776,6 +1838,18 @@ char *s;
     char *tmp;
 #endif
 
+#if defined(REG_COMP) /* Peter Doemel, 10-Feb-1993 */
+    int status;
+    regex_t preg;
+
+    if ((status = regcomp(&preg, s, 0)) != 0) {
+       scxfree(s);
+       cellerror = CELLERROR;
+       error(regerrmsg(status));
+       return;
+    }
+#endif
+
 #if defined(RE_COMP)
     if ((tmp = re_comp(s)) != (char *)0) {
 	scxfree(s);
@@ -1818,25 +1892,30 @@ char *s;
 	}
 	if (r == endr && c == endc) {
 	    error("String not found");
-#if defined(REGCMP)
+#if defined(REG_COMP) /* Peter Doemel, 10-Feb-1993 */
+        regfree(&preg);
+#elif defined(REGCMP)
 	    free(tmp);
 #endif
 	    return;
 	}
 	p = *ATBL(tbl, r, c);
     } while(col_hidden[c] || !p || !(p->label)
-#if defined(RE_COMP)
-		  			|| (re_exec(p->label) == 0));
+
+#if defined(REG_COMP) /* Peter Doemel, 10-Feb-1993 */
+                        || (regexec(&preg, p->label, (size_t)0, NULL, 0) != 0));
+#elif defined(RE_COMP)
+                        || (re_exec(p->label) == 0));
+#elif defined(REGCMP)
+                        || (regex(tmp, p->label) == (char *)0));
 #else
-#if defined(REGCMP)
-				|| (regex(tmp, p->label) == (char *)0));
-#else
-					|| (strcmp(s, p->label) != 0));
-#endif
+			|| (strcmp(s, p->label) != 0));
 #endif
     currow = r;
     curcol = c;
-#if defined(REGCMP)
+#if defined(REG_COMP) /* Peter Doemel, 10-Feb-1993 */
+    regfree(&preg);
+#elif defined(REGCMP)
     free(tmp);
 #endif
 }
@@ -2579,25 +2658,3 @@ int row, col;
     }
 }
 
-#ifdef RINT
-/**	round-to-even, also known as ``banker's rounding''.
-	With round-to-even, a number exactly halfway between two values is
-	rounded to whichever is even; e.g. rnd(0.5)=0, rnd(1.5)=2,
-	rnd(2.5)=2, rnd(3.5)=4.  This is the default rounding mode for
-	IEEE floating point, for good reason: it has better numeric
-	properties.  For example, if X+Y is an integer,
-	then X+Y = rnd(X)+rnd(Y) with round-to-even,
-	but not always with sc's rounding (which is
-	round-to-positive-infinity).  I ran into this problem when trying to
-	split interest in an account to two people fairly.
-**/
-double      
-rint(d)
-double d;
-{
-	/* as sent */
-	double fl = floor(d),  fr = d - fl;
-	return ((fr < 0.5) || ((fr == 0.5) && (fl == floor(fl/2) * 2)))
-		? fl : ceil(d);
-}
-#endif
