@@ -13,6 +13,7 @@
 
 
 #include <sys/types.h>
+#include "config.h"
 
 #if defined(BSD42) || defined(BSD43)
 #include <sys/ioctl.h>
@@ -83,9 +84,11 @@ static	void	charout();
 /*#include <term.h>*/
 extern int	tgetent(char *, char *);
 extern int	tputs(char *, int, int (*)(char));
+char *mystrtof(char *volatile, double *);
 #else	/* __STDC__ */
 extern int	tgetent();
 extern int	tputs();
+char *mystrtof();
 #endif	/* __STDC__ */
 
 jmp_buf wakeup;
@@ -222,7 +225,7 @@ yylex ()
 	}
 	if (*p=='.' || *p == 'e' || *p == 'E') {
 	    ret = FNUMBER;
-	    p = strtof(nstart, &yylval.fval);
+	    p = mystrtof(nstart, &yylval.fval);
 	} else {
 	    /* A NUMBER must hold at least MAXROW and MAXCOL */
 	    /* This is consistent with a short row and col in struct ent */
@@ -299,12 +302,11 @@ atocol (string, len)
  * p is advanced.
  */
 
-char *
-strtof(p, res)
+char * mystrtof(p, res)
 #ifdef __STDC__
-char *volatile p;
+  char *volatile p;
 #else
-char *p;
+  char *p;
 #endif
 double *res;
 {
