@@ -14,6 +14,7 @@
 
 #include <sys/types.h>
 #include <signal.h>
+#include "config.h"
 #ifdef DOINGX
 #include <X11/Xlib.h>
 #include <X11/Xutil.h>
@@ -91,7 +92,6 @@ char line[FBUFLEN];
 int changed;
 struct ent *to_fix;
 int modflg;
-int numeric;
 char *mdir;
 int showsc, showsr;	/* Starting cell for highlighted range */
 #ifdef RIGHT_CBUG
@@ -113,14 +113,16 @@ int  showrange = 0;	/* Causes ranges to be highlighted		  */
 int  showneed  = 0;	/* Causes cells needing values to be highlighted  */
 int  showexpr  = 0;	/* Causes cell exprs to be displayed, highlighted */
 
-int  autocalc = 1 ;	/* 1 to calculate after each update */
+int  numeric;		/* data entry mode: 1 for numeric                 */ /* Peter Doemel, 11-Feb-1993 */
+int  autocalc;		/* 1 to calculate after each update               */
+int  calc_order;	/* order of calculation: BYROWS or BYCOLS         */
+int  craction = 0;	/* CRCOLS for down, CRROWS for right              */
+
 int  autolabel = 1;     /* If room, causes label to be created after a define*/
-int  showcursor = SHOWCURSOR; /* Causes cursor to be displayed */
-int  calc_order = BYROWS;
+int  showcursor = SHOWCURSOR;	/* Causes cursor to be displayed */
 int  tbl_style = 0;	/* headers for T command output */
 int  rndinfinity = 0;
 int  numeric_field = 0; /* Started the line editing with a number */
-int  craction = 0;	/* 1 for down, 2 for right */
 int  rowlimit = -1;
 int  collimit = -1;
 #if !defined(DOINGX) && defined(SIGWINCH)
@@ -241,7 +243,7 @@ char  **argv;
     int Mopt = 0;
     int Nopt = 0;
     int Copt = 0; 
-    int Ropt = 0;
+/*    int Ropt = 0; */	/* commented by Peter Doemel, 11-Feb-1993 */
     char **copyv = argv;	  /*  Added to change font size with  -fn */
     int copyc = argc;
 
@@ -283,10 +285,11 @@ char  **argv;
 	    case 'c':
 		    Copt = 1;
 		    break;
-	    case 'r':
+/*	    case 'r':
 		    Ropt = 1;
-		    break;
+		    break; */	/* commented by Peter Doemel, 11-Feb-1993 */
 	    case 'f':	 	/*  -fn font size */
+	    	    if (argv[0][1] != 'n') goto ILLEGALOPTION;
 		    argv++;
 		    argc--;
 		    /*userfont = strdup(argv[0]);*/
@@ -305,7 +308,7 @@ char  **argv;
 		    print_help();
                     exit(1);
 	    default:
-		    (void) fprintf(stderr,"%s: unrecognized option: \"%c\"\n",
+ILLEGALOPTION:	    (void) fprintf(stderr,"%s: unrecognized option: \"%c\"\n",
 			progname,argv[0][1]);
 		    print_help();
 		    exit(1);
@@ -342,6 +345,7 @@ char  **argv;
     revmsg [strlen (revmsg) - 2] = 0;		/* erase last character */
     (void) strcat (revmsg, ":  Type '?' for help.");
 
+#if 0 /* original code was: */
     if (argc > 1) {
 	(void) strcpy(curfile,argv[1]);
 	readfile (argv[1], 0);
@@ -350,16 +354,25 @@ char  **argv;
     if (Mopt)
 	autocalc = 0;
     if (Nopt)
-	numeric = 1;
+	numeric = 0;	/* now according to documentation, Peter Doemel, 11-Feb-1993 */
     if (Copt)
 	calc_order = BYCOLS;
     if (Ropt)
 	calc_order = BYROWS;
+#else	/* Peter Doemel, 11-Feb-1993 */
+    autocalc = Mopt ? 0 : 1;
+    numeric = Nopt ? 0 : 1;
+    calc_order = Copt ? BYCOLS : BYROWS;
 
-    modflg = 0;
+    if (argc > 1) {	/* moved here by Peter Doemel, 25-Feb-1993 */
+	(void) strcpy(curfile,argv[1]);
+	readfile (argv[1], 0);
+    }
+#endif
 #ifdef VENIX
     setbuf (stdin, NULL);
 #endif
+    modflg = 0;
     FullUpdate++;
 
     while (inloop) { running = TRUE;
@@ -540,7 +553,7 @@ char  **argv;
 		    numeric_field = 0;
 		    write_line(ctl('m'));
 		    switch(craction) {
-		      case CRROWS:
+		      case CRCOLS:
 			if ((rowlimit >= 0) && (currow >= rowlimit)) {
 			    forwcol(1);
 			    currow = 0;
@@ -549,7 +562,7 @@ char  **argv;
 			    forwrow(1);
 			}
 			break;
-		      case CRCOLS:
+		      case CRROWS:
 			if ((collimit >= 0) && (curcol >= collimit)) {
 			    forwrow(1);
 			    curcol = 0;
@@ -1957,10 +1970,10 @@ int	opt;
 		if (craction >= 3)
 			craction = 0;
 		switch(craction) {
-			case CRROWS:
+			case CRCOLS:
 				error("Down row after new line");
 				break;
-			case CRCOLS:
+			case CRROWS:
 				error("Right column after new line");
 				break;
 			default:
