@@ -21,6 +21,10 @@
 #define MINCOLS 30 
 #define	ABSMAXCOLS 702	/* absolute cols: ZZ (base 26) */
 
+#ifdef PSC
+#define error(s) fprintf(stderr,s)
+#endif
+
 #ifdef DOINGX
 /*the following give the minimum size of the main window, in text coordinates*/ 
 #define MIN_COLS 80
@@ -36,8 +40,8 @@
 #define MAXROW  25 
 #define MAXCOL  25      /* moved from matrix.c */
 
-#define CRROWS 1
-#define CRCOLS 2
+#define CRCOLS 1
+#define CRROWS 2
 #define RESCOL 4	/* columns reserved for row numbers */
 /*#ifdef DOINGX*/
 #define RESROW 4 /* rows reserved for prompt, error, and column numbers */
@@ -79,14 +83,6 @@
 # endif
 #endif
 
-#if (defined(BSD42) || defined(BSD43)) && !defined(strrchr)
-#define strrchr rindex
-#endif
-
-#if (defined(BSD42) || defined(BSD43)) && !defined(strchr)
-#define strchr index
-#endif
-
 #ifndef FALSE
 # define	FALSE	0
 # define	TRUE	1
@@ -311,8 +307,8 @@ extern int	linelim;
 extern int	changed;
 extern struct ent *to_fix;
 extern int	showsc, showsr;
-extern char     prvstring[1024];/*to store last string Bob Parbs 12-92 */
-extern char	stringbuf[1024];
+/*extern char     prvstring[1024];/*to store last string Bob Parbs 12-92 */
+extern char	stringbuf[FBUFLEN];
 extern int	maintextrows,	/* text rows in mainwin */
 		maintextcols;	/* text cols in mainwin */
 extern int	running;	/* are we done? -be careful on use... */
@@ -433,7 +429,6 @@ extern void	startdisp(void);
 extern void	startshow(void);
 extern void	stopdisp(void);
 extern void	str_search(char *);
-extern char *	strtof(char *volatile, double *);
 extern void	sync_ranges(void);
 extern void	sync_refs(void);
 extern void	tblprintfile(char *, int, int, int, int);
@@ -577,7 +572,6 @@ extern void	startdisp();
 extern void	startshow();
 extern void	stopdisp();
 extern void	str_search();
-extern char *	strtof();
 extern void     submatrix();              /* Bob Parbs 12-92 */
 extern void	sync_ranges();
 extern void	sync_refs();
@@ -630,7 +624,8 @@ extern int	tbl_style;
 
 #endif
 
-#if defined(BSD42) || defined(BSD43) && !defined(ultrix)
+#if ( defined(BSD42) || defined(BSD43) || defined(__convex__) ) && !defined(ultrix) && !defined(__osf__)
+
 #define	memcpy(dest, source, len)	bcopy(source, dest, (unsigned int)len);
 #define	memset(dest, zero, len)		bzero((dest), (unsigned int)(len));
 #else
@@ -646,6 +641,12 @@ extern int	tbl_style;
 #define	SHOWCURSOR	TRUE
 #endif
 
+#ifndef CASEINSENSITIVECMDLINE	/* Peter Doemel, 11-Feb-1993 */
+# if defined(VMS) || defined(MSDOS)
+#  define CASEINSENSITIVECMDLINE
+# endif
+#endif
+
 /*
  * Declarations of standard functions used in various places.  Mostly
  * to shut up line and 'gcc -Wall'.
@@ -656,7 +657,6 @@ extern int	tbl_style;
 #include <unistd.h>
 #include <ctype.h>
 
-extern int	kill();
 extern int	re_exec();
 extern int	stty();
 extern int	wait();
