@@ -7,11 +7,13 @@
  *
  *              More mods Robert Bond, 12/86
  *		More mods by Alan Silverstein, 3-4/88, see list of changes.
+ *		More mods by Peter Doemel, 2/93: static prvstring in update
  *		Currently supported by gator!sawmill!buhrt (Jeff Buhrt)
  *		$Revision: 6.21 A $
  *
  */
 
+#include "config.h"
 
 #ifdef DOINGX
 #include <stdio.h>
@@ -84,9 +86,14 @@ int	anychanged;	/* did any cell really change in value? */
     register r;
     register i;
     static	int	lastcurcol = -1, lastcurrow = -1;
+#if 0	/* this was the original code of xspread 2.1 */
     char field[FBUFLEN]; /*moved by B.P. 12-92 */
     char prvstring[FBUFLEN];
-
+#else	/* the modified (better working) code looks like this:
+	 * (Peter Doemel, 10-Feb-1993)
+	 */
+    static char field[FBUFLEN], prvstring[FBUFLEN];
+#endif
     /*
      * place the cursor on the screen, set col, curcol, stcol, lastcol as
      * needed
@@ -182,6 +189,7 @@ if ((curcol != lastcurcol) || FullUpdate)
 
     /* Get rid of cursor standout on the cell at previous cursor position */
 #ifdef DOINGX
+#if 0	/* this was the original code of xspread 2.1: */
 /* FIXME*/
 /* following statement modified by Bob Parbs 12-92 */
     if (showcell && !FullUpdate)
@@ -197,6 +205,18 @@ if ((curcol != lastcurcol) || FullUpdate)
 		       textcol(fwidth[prvcol]),textrow(0));
     
 
+#else	/* I think the following code looks clearer:
+	 * (Peter Doemel, 10-Feb-1993)
+	 */
+    if (showcell && !FullUpdate) {
+	XDrawImageString(dpy, mainwin, maingc,
+		         textcol(prvmx), textrow(prvmy),
+		         prvstring, strlen(prvstring) );
+	XFillRectangle(dpy, mainwin, invertgc, textcol(prvmx),
+		       (textrow(prvmy-1)+4),
+		       textcol(fwidth[prvcol]),textrow(0));
+    }
+#endif
 #else
     if (!FullUpdate)
     {	if (showcell)
@@ -223,7 +243,7 @@ if ((curcol != lastcurcol) || FullUpdate)
 
     /* relabel the rows and columns if a full update is performed */
     if (FullUpdate || standlast) {
-#if DOINGX
+#ifdef DOINGX
         cleardownfrom(2);
 #else
 	(void) move(2, 0);
@@ -234,7 +254,7 @@ if ((curcol != lastcurcol) || FullUpdate)
 	for (row=RESROW, i=strow; i <= mxrow; i++) {
 		if (row_hidden[i]) 
 			continue;
-#if DOINGX
+#ifdef DOINGX
 		if (maxrows < 1000)
 			sprintf(stringbuf, "%-*d", RESCOL-1, i);
 		else
@@ -251,7 +271,7 @@ if ((curcol != lastcurcol) || FullUpdate)
 #endif
 	    row++;
 	}
-#if DOINGX
+#ifdef DOINGX
         /* the following will work as long as RESCOL<20.  It is 
 	 * more efficient than the usual sprintf(stringbuf..) and
 	 * XDrawString(...strlen(stringbuf)) combination
@@ -482,7 +502,13 @@ if ((curcol != lastcurcol) || FullUpdate)
 				    do_stand ? maingcreversed : maingc,
 				    textcol(c + fwidth[col] - strlen(field)),
 				    textrow(r), field, strlen(field));
+#if 0	/* this was the original code of xspread 2.1 */
                                     *prvstring = *field;
+#else	/* I'm not sure what the intention was for this, but I think
+	 * the following looks safer: (Peter Doemel, 10-Feb-1993)
+	 */
+				    strncpy( prvstring, field, FBUFLEN);
+#endif
 #else
 				for(i = 0; i < fwidth[col] - strlen(field);i++)
 					(void)addch(' ');
